@@ -117,7 +117,7 @@ sub end_pod {
 
     my $headblock = sprintf "%s\n%s\n\t<title>%s</title>\n",
         qq(<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">),
-        qq(<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">\n<head>),
+        qq(<html xmlns="http://www.w3.org/1999/xhtml" xml:lang=").$self->{Lang}.qq(">\n<head>),
         _htmlEscape( $self->{doctitle} );
     $headblock .= $self->_makeMeta if $self->{MakeMeta};
 
@@ -611,17 +611,13 @@ sub gen_html {
     my $doc        = $args{doc};
     my $components = $args{components};
     my $mgr_desc   = $args{desc};
-
     $self->current_files_output_path( $doc->get_output_path );
-
     $self->_prepare($doc, $components, $mgr_desc);
-#    local $SIG{__WARN__} = sub { };
+#   local $SIG{__WARN__} = sub { };
     $self->parse_from_file($doc->origin);
     my $title = $self->_get_title;
     $doc->title($title);
-
     $self->current_files_output_path('');
-
     return $self->asString;
 }
 
@@ -632,11 +628,12 @@ sub _prepare {
     $self->{MakeMeta}   = 0;
     $self->{TopLinks}   = $components->{arrow}->tag($doc);
     $self->{MakeIndex}  = $doc->config->index;
+    $self->{Lang}       = $doc->config->lang;
     $self->initialize();
     $self->addHeadText($components->{css}->tag($doc));
     $self->addHeadText(qq|<meta http-equiv="Content-Type" content="text/html; charset=$charset" />\n|);
     $self->addBodyOpenText($self->_get_data($doc, $mgr_desc));
-	$self->addBodyCloseText(
+    $self->addBodyCloseText(
         qq|<div class="footer">generated by <a href="http://search.cpan.org/perldoc?|
         .URI::Escape::uri_escape("Pod::ProjectDocs")
         .qq|">Pod::ProjectDocs</a></div>|
